@@ -91,8 +91,8 @@ namespace gnote {
   NoteWindow::NoteWindow(Note & note)
     : m_note(note)
     , m_name(note.get_title())
-    , m_height(360)
-    , m_width(450)
+    , m_height(450)
+    , m_width(600)
     , m_find_handler(note)
     , m_global_keys(NULL)
     , m_enabled(true)
@@ -118,6 +118,7 @@ namespace gnote {
 
     // Sensitize the Link toolbar button on text selection
     m_mark_set_timeout = new utils::InterruptableTimeout();
+    m_mark_set_timeout->signal_timeout.connect(sigc::mem_fun(*m_text_menu, &NoteTextMenu::refresh_state));
     note.get_buffer()->signal_mark_set().connect(
       sigc::mem_fun(*this, &NoteWindow::on_selection_mark_set));
 
@@ -204,8 +205,11 @@ namespace gnote {
 
   void NoteWindow::hint_size(int & width, int & height)
   {
+    if (Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
+          Preferences::AUTOSIZE_NOTE_WINDOW)) {
     width = m_width;
     height = m_height;
+    }
   }
 
   void NoteWindow::size_internals()
@@ -406,11 +410,12 @@ namespace gnote {
     image->property_icon_size() = GTK_ICON_SIZE_MENU;
     text_button->set_image(*image);
     text_button->signal_clicked()
-      .connect(boost::bind(sigc::mem_fun(*this, &NoteWindow::on_text_button_clicked), text_button));
+      .connect(sigc::mem_fun(*this, &NoteWindow::on_text_button_clicked));
     text_button->property_margin_left() = 12;
     text_button->show_all();
     grid->attach(*text_button, grid_col++, 0, 1, 1);
     text_button->set_tooltip_text(_("Set properties of text"));
+    m_text_menu->property_attach_widget() = text_button;
 
     m_important_action = utils::CheckAction::create("mark-important");
     m_important_action->set_label(_("Is Important"));
@@ -598,9 +603,8 @@ namespace gnote {
     m_note.set_pinned(!m_note.is_pinned());
   }
 
-  void NoteWindow::on_text_button_clicked(Gtk::Button *button)
+  void NoteWindow::on_text_button_clicked()
   {
-    m_text_menu->property_attach_widget() = button;
     m_text_menu->show_all();
     utils::popup_menu(*m_text_menu, NULL);
   }
